@@ -249,7 +249,7 @@ define ([
             }
             console.log("miniMenu", mm);
             console.log("entries", entries);
-            r = "<div class='minimenu'>";
+            r = "<div class='minimenu' id='minimenu'>";
             if (entries.length > 1) {
                 r += "<div class='minimenuleft'>";
                 // r += 'Menu:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
@@ -360,7 +360,7 @@ define ([
             r += '</p>';
 
             r += '<p class="alignright"><span id="userbox">';
-            r += appLib.fillUserBox();
+            r += appLib.userBoxContent();
             r += '</span></p>';
 
             r += '</div>';
@@ -381,7 +381,6 @@ define ([
                 r += 'Plack session ID: ' + cf('sessionID');
                 r += ' (last_seen ' + cf('sessionLastSeen') + ')</br>';
             }
-            r += '<div class="d3"></div>';
             return r;
         }, // body
 
@@ -583,14 +582,15 @@ define ([
             // dmn is dmenu name
             // dmo is dmenu object
             var dmo = target.pull(dmn),
-                r = '',
-                len = dmo.entries.length,
+                entry,
                 i,
-                entry;
+                len,
+                r = '';
         
             r += '<form id="' + dmn + '"><br><b>' + dmo.title + '</b><br><br>';
 
             dmo.entries.unshift(null);
+            len = dmo.entries.length;
             for (i = 1; i < len; i += 1) {
                 // the entries are names of targets
                 entry = target.pull(dmo.entries[i]);
